# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Annotated, Any, Literal, Optional, Union

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    EvidenceRefType,
    ProtocolStepItemType,
    ProtocolTimeOfDay,
    UserGoalType,
    UserProtocolStatus,
)


class UpdateUserProtocol(BaseModel):
    update_user_protocol: Optional["UpdateUserProtocolUpdateUserProtocol"] = Field(
        alias="updateUserProtocol"
    )


class UpdateUserProtocolUpdateUserProtocol(BaseModel):
    id: str
    user_id: str = Field(alias="userId")
    title: str
    goal_type: Optional[UserGoalType] = Field(alias="goalType")
    status: UserProtocolStatus
    source_protocol_id: Optional[str] = Field(alias="sourceProtocolId")
    steps_structured: list["UpdateUserProtocolUpdateUserProtocolStepsStructured"] = (
        Field(alias="stepsStructured")
    )
    evidence_refs: list["UpdateUserProtocolUpdateUserProtocolEvidenceRefs"] = Field(
        alias="evidenceRefs"
    )
    safety: Optional["UpdateUserProtocolUpdateUserProtocolSafety"]
    last_edited_at: Optional[Any] = Field(alias="lastEditedAt")
    created_at: Any = Field(alias="createdAt")
    updated_at: Any = Field(alias="updatedAt")


class UpdateUserProtocolUpdateUserProtocolStepsStructured(BaseModel):
    label: Optional[str]
    time_of_day: Optional[ProtocolTimeOfDay] = Field(alias="timeOfDay")
    items: list["UpdateUserProtocolUpdateUserProtocolStepsStructuredItems"]


class UpdateUserProtocolUpdateUserProtocolStepsStructuredItems(BaseModel):
    type: ProtocolStepItemType
    ref_id: Optional[str] = Field(alias="refId")
    name_override: Optional[str] = Field(alias="nameOverride")
    dosage: Optional[str]
    timing: Optional[str]
    notes: Optional[str]
    item_entity: Optional[
        Annotated[
            Union[
                "UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityProduct",
                "UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityCompound",
            ],
            Field(discriminator="typename__"),
        ]
    ] = Field(alias="itemEntity")


class UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityProduct(
    BaseModel
):
    typename__: Literal["Product"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityCompound(
    BaseModel
):
    typename__: Literal["Compound"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class UpdateUserProtocolUpdateUserProtocolEvidenceRefs(BaseModel):
    type: EvidenceRefType
    ref_id: Optional[str] = Field(alias="refId")
    label: Optional[str]
    url: Optional[str]
    episode_id: Optional[str] = Field(alias="episodeId")
    timestamps: list[int]
    notes: Optional[str]
    evidence_ref_entity: Optional[
        Annotated[
            Union[
                "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityArticle",
                "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
                "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityEpisode",
                "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityExternal",
            ],
            Field(discriminator="typename__"),
        ]
    ] = Field(alias="evidenceRefEntity")


class UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityArticle(
    BaseModel
):
    typename__: Literal["Article"] = Field(alias="__typename")
    id: str
    title: str
    article_summary: str = Field(alias="articleSummary")


class UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityCaseStudy(
    BaseModel
):
    typename__: Literal["CaseStudy"] = Field(alias="__typename")
    id: str
    title: str
    summary: str


class UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityEpisode(
    BaseModel
):
    typename__: Literal["Episode"] = Field(alias="__typename")
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


class UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityExternal(
    BaseModel
):
    typename__: Literal["External"] = Field(alias="__typename")
    url: Optional[str]
    label: Optional[str]


class UpdateUserProtocolUpdateUserProtocolSafety(BaseModel):
    warnings: list[str]
    contraindications: list[str]
    interactions: list[str]
    notes: Optional[str]


UpdateUserProtocol.model_rebuild()
UpdateUserProtocolUpdateUserProtocol.model_rebuild()
UpdateUserProtocolUpdateUserProtocolStepsStructured.model_rebuild()
UpdateUserProtocolUpdateUserProtocolStepsStructuredItems.model_rebuild()
UpdateUserProtocolUpdateUserProtocolEvidenceRefs.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeletePerson(BaseModel):
    delete_person: "DeletePersonDeletePerson" = Field(alias="deletePerson")


class DeletePersonDeletePerson(BaseModel):
    id: str
    name: str


DeletePerson.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteUserProfile(BaseModel):
    delete_user_profile: "DeleteUserProfileDeleteUserProfile" = Field(
        alias="deleteUserProfile"
    )


class DeleteUserProfileDeleteUserProfile(BaseModel):
    deleted_count: int = Field(alias="deletedCount")


DeleteUserProfile.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Annotated, Literal, Optional, Union

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    EvidenceRefType,
    ProtocolCategory,
    ProtocolStepItemType,
    ProtocolTimeOfDay,
)


class Protocol(BaseModel):
    protocol: Optional["ProtocolProtocol"]


class ProtocolProtocol(BaseModel):
    id: str
    name: str
    description: Optional[str]
    categories: list[ProtocolCategory]
    goals: list[str]
    steps: list[str]
    cautions: list[str]
    aliases: list[str]
    source_url: Optional[str] = Field(alias="sourceUrl")
    steps_structured: Optional[list["ProtocolProtocolStepsStructured"]] = Field(
        alias="stepsStructured"
    )
    evidence_refs: list["ProtocolProtocolEvidenceRefs"] = Field(alias="evidenceRefs")
    safety: Optional["ProtocolProtocolSafety"]
    products: list["ProtocolProtocolProducts"]
    compounds: list["ProtocolProtocolCompounds"]


class ProtocolProtocolStepsStructured(BaseModel):
    label: Optional[str]
    time_of_day: Optional[ProtocolTimeOfDay] = Field(alias="timeOfDay")
    items: list["ProtocolProtocolStepsStructuredItems"]


class ProtocolProtocolStepsStructuredItems(BaseModel):
    type: ProtocolStepItemType
    ref_id: Optional[str] = Field(alias="refId")
    name_override: Optional[str] = Field(alias="nameOverride")
    dosage: Optional[str]
    timing: Optional[str]
    notes: Optional[str]
    item_entity: Optional[
        Annotated[
            Union[
                "ProtocolProtocolStepsStructuredItemsItemEntityProduct",
                "ProtocolProtocolStepsStructuredItemsItemEntityCompound",
            ],
            Field(discriminator="typename__"),
        ]
    ] = Field(alias="itemEntity")


class ProtocolProtocolStepsStructuredItemsItemEntityProduct(BaseModel):
    typename__: Literal["Product"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class ProtocolProtocolStepsStructuredItemsItemEntityCompound(BaseModel):
    typename__: Literal["Compound"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class ProtocolProtocolEvidenceRefs(BaseModel):
    type: EvidenceRefType
    ref_id: Optional[str] = Field(alias="refId")
    label: Optional[str]
    url: Optional[str]
    episode_id: Optional[str] = Field(alias="episodeId")
    timestamps: list[int]
    notes: Optional[str]
    evidence_ref_entity: Optional[
        Annotated[
            Union[
                "ProtocolProtocolEvidenceRefsEvidenceRefEntityArticle",
                "ProtocolProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
                "ProtocolProtocolEvidenceRefsEvidenceRefEntityEpisode",
                "ProtocolProtocolEvidenceRefsEvidenceRefEntityExternal",
            ],
            Field(discriminator="typename__"),
        ]
    ] = Field(alias="evidenceRefEntity")


class ProtocolProtocolEvidenceRefsEvidenceRefEntityArticle(BaseModel):
    typename__: Literal["Article"] = Field(alias="__typename")
    id: str
    title: str
    summary: str


class ProtocolProtocolEvidenceRefsEvidenceRefEntityCaseStudy(BaseModel):
    typename__: Literal["CaseStudy"] = Field(alias="__typename")
    id: str
    title: str
    summary: str


class ProtocolProtocolEvidenceRefsEvidenceRefEntityEpisode(BaseModel):
    typename__: Literal["Episode"] = Field(alias="__typename")
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


class ProtocolProtocolEvidenceRefsEvidenceRefEntityExternal(BaseModel):
    typename__: Literal["External"] = Field(alias="__typename")
    url: Optional[str]
    label: Optional[str]


class ProtocolProtocolSafety(BaseModel):
    warnings: list[str]
    contraindications: list[str]
    interactions: list[str]
    notes: Optional[str]


class ProtocolProtocolProducts(BaseModel):
    id: str
    name: str
    description: Optional[str]


class ProtocolProtocolCompounds(BaseModel):
    id: str
    name: str
    description: Optional[str]


Protocol.model_rebuild()
ProtocolProtocol.model_rebuild()
ProtocolProtocolStepsStructured.model_rebuild()
ProtocolProtocolStepsStructuredItems.model_rebuild()
ProtocolProtocolEvidenceRefs.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateEpisode(BaseModel):
    create_episode: "CreateEpisodeCreateEpisode" = Field(alias="createEpisode")


class CreateEpisodeCreateEpisode(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")
    episode_number: Optional[int] = Field(alias="episodeNumber")


CreateEpisode.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class Compound(BaseModel):
    compound: Optional["CompoundCompound"]


class CompoundCompound(BaseModel):
    id: str
    name: str
    description: Optional[str]
    aliases: list[str]
    media_links: Optional[list["CompoundCompoundMediaLinks"]] = Field(
        alias="mediaLinks"
    )
    products: list["CompoundCompoundProducts"]
    case_studies: list["CompoundCompoundCaseStudies"] = Field(alias="caseStudies")


class CompoundCompoundMediaLinks(BaseModel):
    url: str
    description: Optional[str]


class CompoundCompoundProducts(BaseModel):
    id: str
    name: str
    description: Optional[str]


class CompoundCompoundCaseStudies(BaseModel):
    id: str
    title: str
    summary: str


Compound.model_rebuild()
CompoundCompound.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class VectorSearchProducts(BaseModel):
    vector_search_products: Optional[
        list["VectorSearchProductsVectorSearchProducts"]
    ] = Field(alias="vectorSearchProducts")


class VectorSearchProductsVectorSearchProducts(BaseModel):
    id: str
    name: str
    description: str
    score: Optional[float]


VectorSearchProducts.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Annotated, Literal, Optional, Union

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    EvidenceRefType,
    ProtocolCategory,
    ProtocolStepItemType,
    ProtocolTimeOfDay,
)


class UpdateProtocol(BaseModel):
    update_protocol: Optional["UpdateProtocolUpdateProtocol"] = Field(
        alias="updateProtocol"
    )


class UpdateProtocolUpdateProtocol(BaseModel):
    id: str
    name: str
    description: Optional[str]
    categories: list[ProtocolCategory]
    goals: list[str]
    steps: list[str]
    cautions: list[str]
    aliases: list[str]
    source_url: Optional[str] = Field(alias="sourceUrl")
    steps_structured: Optional[list["UpdateProtocolUpdateProtocolStepsStructured"]] = (
        Field(alias="stepsStructured")
    )
    evidence_refs: list["UpdateProtocolUpdateProtocolEvidenceRefs"] = Field(
        alias="evidenceRefs"
    )
    safety: Optional["UpdateProtocolUpdateProtocolSafety"]
    products: list["UpdateProtocolUpdateProtocolProducts"]
    compounds: list["UpdateProtocolUpdateProtocolCompounds"]


class UpdateProtocolUpdateProtocolStepsStructured(BaseModel):
    label: Optional[str]
    time_of_day: Optional[ProtocolTimeOfDay] = Field(alias="timeOfDay")
    items: list["UpdateProtocolUpdateProtocolStepsStructuredItems"]


class UpdateProtocolUpdateProtocolStepsStructuredItems(BaseModel):
    type: ProtocolStepItemType
    ref_id: Optional[str] = Field(alias="refId")
    name_override: Optional[str] = Field(alias="nameOverride")
    dosage: Optional[str]
    timing: Optional[str]
    notes: Optional[str]
    item_entity: Optional[
        Annotated[
            Union[
                "UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityProduct",
                "UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityCompound",
            ],
            Field(discriminator="typename__"),
        ]
    ] = Field(alias="itemEntity")


class UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityProduct(BaseModel):
    typename__: Literal["Product"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityCompound(BaseModel):
    typename__: Literal["Compound"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class UpdateProtocolUpdateProtocolEvidenceRefs(BaseModel):
    type: EvidenceRefType
    ref_id: Optional[str] = Field(alias="refId")
    label: Optional[str]
    url: Optional[str]
    episode_id: Optional[str] = Field(alias="episodeId")
    timestamps: list[int]
    notes: Optional[str]
    evidence_ref_entity: Optional[
        Annotated[
            Union[
                "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityArticle",
                "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
                "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityEpisode",
                "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityExternal",
            ],
            Field(discriminator="typename__"),
        ]
    ] = Field(alias="evidenceRefEntity")


class UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityArticle(BaseModel):
    typename__: Literal["Article"] = Field(alias="__typename")
    id: str
    title: str
    article_summary: str = Field(alias="articleSummary")


class UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityCaseStudy(BaseModel):
    typename__: Literal["CaseStudy"] = Field(alias="__typename")
    id: str
    title: str
    summary: str


class UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityEpisode(BaseModel):
    typename__: Literal["Episode"] = Field(alias="__typename")
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


class UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityExternal(BaseModel):
    typename__: Literal["External"] = Field(alias="__typename")
    url: Optional[str]
    label: Optional[str]


class UpdateProtocolUpdateProtocolSafety(BaseModel):
    warnings: list[str]
    contraindications: list[str]
    interactions: list[str]
    notes: Optional[str]


class UpdateProtocolUpdateProtocolProducts(BaseModel):
    id: str
    name: str


class UpdateProtocolUpdateProtocolCompounds(BaseModel):
    id: str
    name: str


UpdateProtocol.model_rebuild()
UpdateProtocolUpdateProtocol.model_rebuild()
UpdateProtocolUpdateProtocolStepsStructured.model_rebuild()
UpdateProtocolUpdateProtocolStepsStructuredItems.model_rebuild()
UpdateProtocolUpdateProtocolEvidenceRefs.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteUserProtocol(BaseModel):
    delete_user_protocol: bool = Field(alias="deleteUserProtocol")



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateEpisode(BaseModel):
    update_episode: Optional["UpdateEpisodeUpdateEpisode"] = Field(
        alias="updateEpisode"
    )


class UpdateEpisodeUpdateEpisode(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")
    episode_number: Optional[int] = Field(alias="episodeNumber")


UpdateEpisode.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateProduct(BaseModel):
    create_product: "CreateProductCreateProduct" = Field(alias="createProduct")


class CreateProductCreateProduct(BaseModel):
    id: str
    name: str
    description: Optional[str]
    ingredients: list[str]


CreateProduct.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EmbedProductDescription(BaseModel):
    embed_product_description: "EmbedProductDescriptionEmbedProductDescription" = Field(
        alias="embedProductDescription"
    )


class EmbedProductDescriptionEmbedProductDescription(BaseModel):
    id: str
    name: str
    description: Optional[str]


EmbedProductDescription.model_rebuild()
